@@ -7,9 +7,8 @@
  * Copyright 2011 Canonical Ltd.
  *
  * This library is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option) any
- * later version.
+ * the terms of version 3 of the GNU Lesser General Public License as published
+ * by the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -156,6 +155,11 @@ _geis_dbus_token_deactivate(GeisBackendToken token, GeisSubscription subscriptio
   return GEIS_STATUS_UNKNOWN_ERROR;
 }
 
+static void
+_geis_dbus_token_free_subscription_pdata(GeisBackendToken token GEIS_UNUSED,
+                                         GeisSubscription subscription GEIS_UNUSED)
+{
+}
 
 static struct GeisBackendTokenVtable _token_vtbl = {
   _geis_dbus_token_clone,
@@ -163,6 +167,7 @@ static struct GeisBackendTokenVtable _token_vtbl = {
   _geis_dbus_token_compose,
   _geis_dbus_token_activate,
   _geis_dbus_token_deactivate,
+  _geis_dbus_token_free_subscription_pdata
 };
 
 
