@@ -12,9 +12,8 @@
  * Copyright 2010, 2011 Canonical Ltd.
  *
  * This library is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option) any
- * later version.
+ * the terms of version 3 of the GNU Lesser General Public License as published
+ * by the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -1262,6 +1261,8 @@ geis_register_device(Geis                    geis,
     GeisAttr attr = geis_attr_new(GEIS_EVENT_ATTRIBUTE_DEVICE,
                                   GEIS_ATTR_TYPE_POINTER,
                                   device);
+    geis_device_ref(device);
+    geis_attr_set_destructor(attr, (GeisAttrDestructor)geis_device_unref);
 
     geis_event_add_attr(event, attr);
     geis_post_event(geis, event);
