@@ -5,9 +5,8 @@
 # Copyright (C) 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of version 3 of the GNU General Public License as
+# published by the Free Software Foundation.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,7 +29,7 @@ if os.path.exists(os.path.join(root_dir, "Makefile.am")):
     ui_dir = data_dir
 else:
     # running from installed
-    data_dir = os.path.join("/usr/share/geisview")
+    data_dir = os.path.join("/usr/local/share/geisview")
     locale_dir = os.path.join(data_dir, "locale")
     ui_dir = data_dir
 
@@ -49,9 +48,8 @@ description = _("A GEIS data viewer.\n\nGEIS Viewer is a part of "
 authors = ["Stephen M. Webb  <stephen.webb@canonical.com"]
 
 LICENSE = _("%s is free software; you can redistribute it and/or modify " 
-       "it under the terms of the GNU General Public License as published by " 
-       "the Free Software Foundation; either version 2 of the License, or " 
-       "(at your option) any later version.\n\n").replace("%s", appname),
+       "it under the terms of version 3 of the GNU General Public License "
+       "as published by the Free Software Foundation.\n\n").replace("%s", appname),
 _("%s is distributed in the hope that it will be useful, "
        "but WITHOUT ANY WARRANTY; without even the implied warranty of "
        "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
